==> org-lsst-ccs-subsystem-fcs-gui-1.3-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/ui/jas/SingleFilterTestJasPlugin.java <==
package org.lsst.ccs.subsystems.fcs.singlefiltertest.ui.jas;

import java.io.PrintWriter;
import org.freehep.application.studio.Studio;
import org.freehep.jas.plugin.console.Console;
import org.freehep.util.FreeHEPLookup;
import org.lsst.ccs.plugin.jas3.LsstSubsystemPlugin;
import org.lsst.ccs.subsystems.fcs.singlefiltertest.ui.SingleFilterTestGUISubsystem;

/**
 *
 * @author tonyj
 */
public class SingleFilterTestJasPlugin extends LsstSubsystemPlugin {

    SingleFilterTestGUISubsystem singleFilterTestGUISubsystem;
    FreeHEPLookup lookup;

    @Override
    protected void postInit() {
        super.postInit();
        singleFilterTestGUISubsystem = new SingleFilterTestGUISubsystem();
        this.getApplication().getPageManager().openPage(singleFilterTestGUISubsystem.getGuiLayout(), "Single Filter Test GUI", null);
        Studio studio = (Studio) Studio.getApplication();
        lookup = studio.getLookup();
        lookup.add(this);
    }

    @Override
    public void disconnectFromMessagingFactory() {
        closeTracerConsole("Single Filter Test Tracer");
        singleFilterTestGUISubsystem.resetGui();
    }

    @Override
    public void initializeRestServices() {
//        registerChannelsForSubsystem("ccs-refrig");
    }

    @Override
    public void resetRestServices() {
//        removeChannelsForSubsystem("ccs-refrig");
    }

    @Override
    public void connectToMessagingFactory() {
        
        singleFilterTestGUISubsystem.initGui();        
        Console c = createTracerConsole("Single Filter Test Tracer", null);
        if ( c != null ) {
                PrintWriter pw = new PrintWriter(c.getOutputStream(null), true);
                singleFilterTestGUISubsystem.setPrintWriter(pw);            
        }

        
    }
    
    
}

==> org-lsst-ccs-subsystem-fcs-gui-1.3.2-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/ui/jas/SingleFilterTestJasPlugin.java <==
package org.lsst.ccs.subsystems.fcs.singlefiltertest.ui.jas;

import java.io.PrintWriter;
import org.freehep.application.studio.Studio;
import org.freehep.util.FreeHEPLookup;
import org.lsst.ccs.plugin.jas3.LsstSubsystemPlugin;
import org.lsst.ccs.subsystems.fcs.singlefiltertest.ui.SingleFilterTestGUISubsystem;

/**
 *
 * @author tonyj
 */
public class SingleFilterTestJasPlugin extends LsstSubsystemPlugin {

    SingleFilterTestGUISubsystem singleFilterTestGUISubsystem;
    FreeHEPLookup lookup;

    @Override
    protected void postInit() {
        super.postInit();
        singleFilterTestGUISubsystem = new SingleFilterTestGUISubsystem();
        singleFilterTestGUISubsystem.initGui();
        this.getApplication().getPageManager().openPage(singleFilterTestGUISubsystem.getGuiLayout(), "Single Filter Test GUI", null);
        Studio studio = (Studio) Studio.getApplication();
        lookup = studio.getLookup();
        lookup.add(this);
    }

    @Override
    public void disconnectFromMessagingFactory() {
        singleFilterTestGUISubsystem.resetGui();
    }

    @Override
    public void initializeRestServices() {
//        registerChannelsForSubsystem("ccs-refrig");
    }

    @Override
    public void resetRestServices() {
//        removeChannelsForSubsystem("ccs-refrig");
    }

    @Override
    public void connectToMessagingFactory() {
        
        singleFilterTestGUISubsystem.initGui();        
//        Console c = createTracerConsole("Single Filter Test Tracer", null);
//        if ( c != null ) {
//                PrintWriter pw = new PrintWriter(c.getOutputStream(null), true);
//                singleFilterTestGUISubsystem.setPrintWriter(pw);            
//        }

        
    }
    
    
}
